==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkEmbeddedWindowPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkEmbeddedWindowPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class 4eb180ddb800c38a gnu_java_awt_peer_gtk_GtkContainerPeer
// @dep_class 1fab6adfb931c3fc gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer
// @dep_class a5aeab3d67282ec6 gnu_java_awt_peer_gtk_GtkFramePeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 3ef33a94bad58118 gnu_java_awt_peer_gtk_GtkWindowPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkFramePeer

#include "gnu/java/awt/peer/gtk/GtkFramePeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_EmbeddedWindow$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$_init$0350c5e0e0ab102b(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, struct _jc_gnu_java_awt_EmbeddedWindow$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$construct$9cb1133c412b8247(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong);
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$create$19106ede39f89465(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong);
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$embed$0d6ae47ed52c6ce1(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$construct$9cb1133c412b8247;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$create$19106ede39f89465;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$embed$0d6ae47ed52c6ce1;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods {
	void	(*construct$9cb1133c412b8247)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong);
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *);
	void	(*create$19106ede39f89465)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong);
	void	(*embed$0d6ae47ed52c6ce1)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkContainerPeer$vmethods	gnu_java_awt_peer_gtk_GtkContainerPeer;
	_jc_gnu_java_awt_peer_gtk_GtkWindowPeer$vmethods	gnu_java_awt_peer_gtk_GtkWindowPeer;
	_jc_gnu_java_awt_peer_gtk_GtkFramePeer$vmethods	gnu_java_awt_peer_gtk_GtkFramePeer;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods	gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs	gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkFramePeer$sub_refs	gnu_java_awt_peer_gtk_GtkFramePeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_refs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_refs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkFramePeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkFramePeer;
    _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkEmbeddedWindowPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkEmbeddedWindowPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class 4eb180ddb800c38a gnu_java_awt_peer_gtk_GtkContainerPeer
// @dep_class 1fab6adfb931c3fc gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer
// @dep_class a5aeab3d67282ec6 gnu_java_awt_peer_gtk_GtkFramePeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 3ef33a94bad58118 gnu_java_awt_peer_gtk_GtkWindowPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkFramePeer

#include "gnu/java/awt/peer/gtk/GtkFramePeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer_H_

// Forward structure declarations
struct _jc_gnu_java_awt_EmbeddedWindow$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$_init$0350c5e0e0ab102b(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, struct _jc_gnu_java_awt_EmbeddedWindow$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$construct$9cb1133c412b8247(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$create$19106ede39f89465(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method$embed$0d6ae47ed52c6ce1(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$construct$9cb1133c412b8247;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$create$19106ede39f89465;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$method_info$embed$0d6ae47ed52c6ce1;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods {
	void	(*construct$9cb1133c412b8247)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong) _JC_JCNI_ATTR;
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *) _JC_JCNI_ATTR;
	void	(*create$19106ede39f89465)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong) _JC_JCNI_ATTR;
	void	(*embed$0d6ae47ed52c6ce1)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkContainerPeer$vmethods	gnu_java_awt_peer_gtk_GtkContainerPeer;
	_jc_gnu_java_awt_peer_gtk_GtkWindowPeer$vmethods	gnu_java_awt_peer_gtk_GtkWindowPeer;
	_jc_gnu_java_awt_peer_gtk_GtkFramePeer$vmethods	gnu_java_awt_peer_gtk_GtkFramePeer;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vmethods	gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_refs	gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkFramePeer$sub_refs	gnu_java_awt_peer_gtk_GtkFramePeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_refs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_refs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkWindowPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkWindowPeer;
    _jc_gnu_java_awt_peer_gtk_GtkFramePeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkFramePeer;
    _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkEmbeddedWindowPeer_H_ */
